@@ -625,45 +625,20 @@ def portal_grade(notebook_path, grading_url, checksum_url, token=None, timeout=N
 # noinspection PyShadowingNames
 @portal.command('validate')
 @click.option('--notebook_path', type=str, required=True)
-@click.option('--checksum_url', type=str, required=True)
 @click.option('--timeout', type=int, default=None)
-@click.option('--token', type=str, required=True)
-def portal_validate(notebook_path, checksum_url, token, timeout):
+def portal_validate(notebook_path, timeout):
     """
     Validate notebook hashes and grade
     """
     head, tail = os.path.split(notebook_path)
     notebook = nbformat.read(notebook_path, as_version=nbformat.NO_CONVERT)
 
-    if checksum:
-        print("Fetching checksum...")
-        response = requests.get(
-            checksum_url,
-            headers={'Authorization': f"Token {token}"},
-        )
-        try:
-            response.raise_for_status()
-        except HTTPError:
-            print(response.content)
-            raise
-        db_checksum = response.json()['checksum']
-
-        print("Validating notebook...")
-        if not utils.is_valid(notebook, db_checksum):
-            print("Checksum mismatch! (a)")
-            sys.exit(1)
-
     print("Executing notebook...")
     cwd = os.getcwd()
     os.chdir(head)
     notebook = utils.execute(notebook, timeout, allow_errors=False)
     os.chdir(cwd)
 
-    if checksum:
-        if not utils.is_valid(notebook, db_checksum):
-            print("Checksum mismatch! (b)")
-            sys.exit(1)
-
     print("Grading notebook...")
     total_score, max_score = utils.grade(notebook)
     print(f"Score: {total_score}/{max_score}")
